brocket
=======

A command line tool for building Amazon Assocate links fast (with as little work as possible).

If you have a link in the clipboard, run this script, then the link on the clipboard becomes an Amazon assocate link.

Brocket Deer
------------

This little utility is named for the `Brocket Deer`_ which lives around the Amazon river. It also sounds like Rocket, but with a 'B' and I was looking for something fast.

_Brocket Deer: https://en.wikipedia.org/wiki/Brocket_deer
